@@ -1,8 +1,8 @@
 package org.evolvis.tartools.rfc822;
 
 /*-
- * Copyright © 2020 mirabilos (t.glaser@tarent.de)
- * Licensor: tarent solutions GmbH, Bonn
+ * Copyright © 2020 mirabilos (t.glaser@qvest-digital.com)
+ * Licensor: Qvest Digital AG, Bonn, Germany
  *
  * Provided that these terms and disclaimer and all copyright notices
  * are retained or reproduced in an accompanying document, permission
@@ -28,7 +28,7 @@ import java.util.List;
 /**
  * For {@link ParserTest}
  *
- * @author mirabilos (t.glaser@tarent.de)
+ * @author mirabilos (t.glaser@qvest-digital.com)
  */
 class TestParser extends Parser {
 
@@ -52,6 +52,7 @@ protected TestParser(final String input)
 	super(input, 16);
 }
 
+@SuppressWarnings("unused")
 static boolean
 isWsp(final int cur, final int next)
 {
